var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { difference } from 'ramda';
import { ReviewStatuses } from "../types";
export function getReviewerIds(sme, session) {
    return sme ? session.teachingReviewerIds : session.conversionReviewerIds;
}
export function getParticipantIds(sme, session) {
    return sme
        ? session.teachingReviewParticipantIds
        : session.conversionReviewParticipantIds;
}
export function isOwner(sme, currentUserId, _a) {
    var teachingOwnerId = _a.teachingOwnerId, conversionOwnerId = _a.conversionOwnerId;
    return sme
        ? teachingOwnerId === currentUserId
        : conversionOwnerId === currentUserId;
}
export function isReviewer(currentUserId, reviewerIds) {
    return (reviewerIds && reviewerIds.length > 0 && reviewerIds.includes(currentUserId));
}
export function isParticipantInReview(currentUserId, participantIds) {
    return (participantIds &&
        participantIds.length > 0 &&
        participantIds.includes(currentUserId));
}
export function isReviewRequested(reviewerIds) {
    return Boolean(reviewerIds && reviewerIds.length > 0);
}
export function allReviewersAreParticipants(reviewerIds, participantIds) {
    return Boolean(reviewerIds &&
        reviewerIds.length > 0 &&
        participantIds &&
        participantIds.length > 0 &&
        equalElements(participantIds, reviewerIds));
}
function equalElements(participantIds, reviewerIds) {
    var participantIdsCopy = typeof participantIds === 'string' ? [participantIds] : __spreadArrays(participantIds);
    var reviewerIdsCopy = typeof reviewerIds === 'string' ? [reviewerIds] : __spreadArrays(reviewerIds);
    var diff = difference(reviewerIdsCopy, participantIdsCopy);
    return diff.length === 0;
}
export function getReviewKiData(auditKiReview) {
    var kiIds = Object.keys(auditKiReview);
    if (kiIds.length === 0) {
        return undefined;
    }
    return kiIds.reduce(function (acc, kiId) {
        var status = auditKiReview[kiId].status;
        var result = __assign({}, acc);
        if (status === ReviewStatuses.APPROVED) {
            result.approved++;
        }
        if (status === ReviewStatuses.REFUSED) {
            result.refused++;
        }
        if (status === ReviewStatuses.PENDING) {
            result.pending++;
        }
        return result;
    }, {
        approved: 0,
        refused: 0,
        pending: 0,
    });
}
export function getReviewKiStatistics(reviewKiData) {
    if (!reviewKiData) {
        return {
            inProgress: false,
            pending: false,
            partialRefuse: false,
            refused: false,
            approved: false,
        };
    }
    var pendingReview = reviewKiData.pending, approvedReview = reviewKiData.approved, refusedReview = reviewKiData.refused;
    var inProgress = pendingReview > 0 && approvedReview > 0 && refusedReview === 0;
    var pending = refusedReview === 0 && approvedReview === 0 && pendingReview > 0;
    var partialRefuse = refusedReview > 0 && (pendingReview > 0 || approvedReview > 0);
    var refused = approvedReview === 0 && pendingReview === 0 && refusedReview > 0;
    var approved = refusedReview === 0 && pendingReview === 0 && approvedReview > 0;
    return {
        inProgress: inProgress,
        pending: pending,
        partialRefuse: partialRefuse,
        refused: refused,
        approved: approved,
    };
}
